Tournament Second Bite, Portsmouth, England February 20th 1999 17 players Matt Green https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/D-w5Ck4_cTM/discussion Matt Green's Alamut Vote Deck -- Portsmouth tournament 20/ii/99 Report. Crypt (12 cards, min=12, max=26, avg=4.5) ----------------------------------------- 2x Mariana Gilbert 4 PRE cel Toreador:1 2x Tansu Bekir 4 OBF cel Assamite:2 1x Husamettin 8 CEL OBF QUI pot pre Assamite:2 1x Melek 7 OBF QUI cel pre Assamite:2 1x Kalinda 6 CEL OBF tha Assamite:2 1x Ramiel DuPre 5 PRE aus cel dom Toreador:1 1x Demetrius Slater 4 aus cel pre Toreador:1 1x Lena Rowe 3 aus obf pre Pander:2 1x Watenda 3 obf Malkavian:2 1x Delilah Easton 2 pre Toreador:1 Library (91 cards) Master (18) 4x Alamut 2x Blood Doll 2x Direct Intervention 3x Dreams of the Sphinx 1x Elysium: The Arboretum 1x KRCG News Radio 1x Market Square 1x Obfuscate 1x Presence 1x Rumor Mill, Tabloid Newspaper, The 1x Sudden Reversal Action (10) 1x Fifth Tradition: Hospitality 7x Legal Manipulations 2x Memory's Fading Glimpse Political Action (21) 3x Banishment 2x Disputed Territory 10x Kine Resources Contested 1x Praxis Seizure: Dublin 1x Praxis Seizure: Istanbul 1x Praxis Seizure: Monaco 1x Praxis Seizure: Paris 1x Revocation of Tyre 1x Toreador Justicar Retainer (3) 1x J. S. Simmons, Esq. 1x Mr. Winthrop 1x Tasha Morgan Action Modifier (22) 4x Aire of Elation 4x Awe 6x Cloak the Gathering 2x Elder Impersonation 6x Lost in Crowds Reaction (7) 7x Wake with Evening's Freshness Combat (10) 2x Behind You! 8x Majesty